#
# spec file for package ghc-base-compat-batteries
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name base-compat-batteries
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.13.1
Release:        2.5
Summary:        Base-compat with extra batteries
License:        MIT
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-compat-devel
BuildRequires:  ghc-base-compat-prof
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-rpm-macros
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-QuickCheck-prof
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-hspec-prof
%endif

%description
Provides functions available in later versions of 'base' to a wider range of
compilers, without requiring you to use CPP pragmas in your code.

This package provides the same API as the
'<http://hackage.haskell.org/package/base-compat base-compat>' library, but
depends on compatibility packages (such as 'semigroups') to offer a wider
support window than 'base-compat', which has no dependencies. Most of the
modules in this library have the same names as in 'base-compat' to make it
easier to switch between the two. There also exist versions of each module with
the suffix '.Repl.Batteries', which are distinct from anything in
'base-compat', to allow for easier use in GHCi.

See
'<https://github.com/haskell-compat/base-compat/blob/master/base-compat/README.markdown#dependencies
here>' for a more comprehensive list of differences between 'base-compat' and
'base-compat-batteries'.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGES.markdown README.markdown

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Thu Nov 16 2023 Peter Simons <psimons@suse.com>
- Drop obsolete dependency on ghc-foldable1-classes-compat.
* Wed Oct 11 2023 Peter Simons <psimons@suse.com>
- Update base-compat-batteries to version 0.13.1.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/base-compat-batteries-0.13.1/src/CHANGES.markdown
* Sat Jun 10 2023 Peter Simons <psimons@suse.com>
- Update base-compat-batteries to version 0.13.0.
  [#]# Changes in 0.13.0 [2023.03.10]
  - This coincides with the `base-compat-0.13.0` release. Refer to the
    [`base-compat` changelog](https://github.com/haskell-compat/base-compat/blob/master/base-compat/CHANGES.markdown#changes-in-0130-20230310)
    for more details.
  - Require `OneTuple-0.4` or later on GHC 7.4+, as that is the first `OneTuple`
    release to backport the `MkSolo` data constuctor for `Solo`. See
    `Data.Tuple.Compat`.
  - Introduce `Data.Foldable1.Compat` and `Data.Bifoldable1.Compat` modules,
    which correspond to changes made in `base-4.18.0.0`. `base-compat-batteries`
    uses the `foldable1-classes-compat` library to backport this code to older
    versions of `base`.
  - Depend on `bifunctor-classes-compat` to backport the `Bifunctor`,
    `Bifoldable`, and `Bitraversable` classes instead of the
    `bifunctors` library, which has more dependencies.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Thu Aug 11 2022 Peter Simons <psimons@suse.com>
- Update base-compat-batteries to version 0.12.2.
  [#]# Changes in 0.12.2 [2022.08.11]
  - This coincides with the `base-compat-0.12.2` release. Refer to the
    [`base-compat` changelog](https://github.com/haskell-compat/base-compat/blob/master/base-compat/CHANGES.markdown#changes-in-0122-20220811)
    for more details.
* Sat Nov 20 2021 psimons@suse.com
- Update base-compat-batteries to version 0.12.1 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Nov 16 2021 psimons@suse.com
- Update base-compat-batteries to version 0.12.1 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Nov  1 2021 psimons@suse.com
- Update base-compat-batteries to version 0.12.1.
  [#]# Changes in 0.12.1 [2021.10.30]
  - Backport `Solo` to the `Data.Tuple.Compat` module. If using `ghc-prim-0.7.0`
    or later, `Solo` is taken from `ghc-prim`. If using an older version of
    `ghc-prim`, `Solo` is taken from the `OneTuple` compatibility library.
  - This coincides with the `base-compat-0.12.1` release. Refer to the
    [`base-compat` changelog](https://github.com/haskell-compat/base-compat/blob/master/base-compat/CHANGES.markdown#changes-in-0121-20211030)
    for more details.
* Thu Sep  2 2021 psimons@suse.com
- Update base-compat-batteries to version 0.12.0 revision 1.
  [#]# Changes in 0.12.0 [2021.08.29]
  - `Data.Semigroup.Compat{.Repl.Batteries}` no longer re-exports the `Option`
    data type or the `option` function, as both have been removed in
    `base-4.16`.
  - This coincides with the `base-compat-0.12.0` release. Refer to the
    [`base-compat` changelog](https://github.com/haskell-compat/base-compat/blob/master/base-compat/CHANGES.markdown#changes-in-0120-20210829)
    for more details.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Oct  6 2020 psimons@suse.com
- Update base-compat-batteries to version 0.11.2.
  [#]# Changes in 0.11.2 [2020.09.30]
  - This coincides with the `base-compat-0.11.2` release. Refer to the
    [`base-compat` changelog](https://github.com/haskell-compat/base-compat/blob/master/base-compat/CHANGES.markdown#changes-in-0112-20200930)
    for more details.
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Sat May  2 2020 psimons@suse.com
- Add base-compat-batteries at version 0.11.1.
